:orphan:

The extension tutorial has moved!
----------------------------------

With the release of JupyterLab 1.0, we've also created a brand-new extension tutorial! This old tutorial is now out-of-date and has been retired, but `you can find the new tutorial here <https://jupyterlab.readthedocs.io/en/stable/developer/extension_tutorial.html>`__.
